#
# spec file for package perl-GnuPG-Interface
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name GnuPG-Interface
Name:           perl-GnuPG-Interface
Version:        1.40.0
Release:        2.2
%define cpan_version 1.04
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Supply object methods for interacting with GnuPG
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BP/BPS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.36
BuildRequires:  perl(Math::BigInt) >= 1.78
BuildRequires:  perl(Moo) >= 0.091011
BuildRequires:  perl(MooX::HandlesVia) >= 0.001004
BuildRequires:  perl(MooX::late) >= 0.014
Requires:       perl(Math::BigInt) >= 1.78
Requires:       perl(Moo) >= 0.091011
Requires:       perl(MooX::HandlesVia) >= 0.001004
Requires:       perl(MooX::late) >= 0.014
Provides:       perl(GnuPG::Fingerprint)
Provides:       perl(GnuPG::Handles)
Provides:       perl(GnuPG::HashInit)
Provides:       perl(GnuPG::Interface) = %{version}
Provides:       perl(GnuPG::Key)
Provides:       perl(GnuPG::Options)
Provides:       perl(GnuPG::PrimaryKey)
Provides:       perl(GnuPG::PublicKey)
Provides:       perl(GnuPG::Revoker)
Provides:       perl(GnuPG::SecretKey)
Provides:       perl(GnuPG::Signature)
Provides:       perl(GnuPG::SubKey)
Provides:       perl(GnuPG::UserAttribute)
Provides:       perl(GnuPG::UserId)
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  gpg2
Requires:       gpg2
# MANUAL END

%description
GnuPG::Interface and its associated modules are designed to provide an
object-oriented method for interacting with GnuPG, being able to perform
functions such as but not limited to encrypting, signing, decryption,
verification, and key-listing parsing.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
PERL_USE_UNSAFE_INC=1 perl Makefile.PL INSTALLDIRS=vendor
%make_build

# MANUAL BEGIN
chmod 755 ./test/fake-gpg-v*

# MANUAL END
%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Dec 14 2023 Tina Müller <tina.mueller@suse.com>
- Remove make test workaround, fixed upstream
* Thu Dec 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.04
  see /usr/share/doc/packages/perl-GnuPG-Interface/Changes
  1.04 - 2023-12-12
  - Use the included fake gpg for better test portability
  - Update tests for gpg 2.4
* Tue Sep 26 2023 Tina Müller <tina.mueller@suse.com>
- Add permission fix for tests
* Sat Sep 16 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.03
  see /usr/share/doc/packages/perl-GnuPG-Interface/Changes
  1.03 - 2023-09-14
  - Add fix for running in taint mode for Perl 5.38.0(thanks to Andrew Ruthven)
* Tue Apr 13 2021 lars@linux-schulserver.de - 1.02
- update to 1.02:
  + Work around an issue with CLI options for deleting secret
    keys in gpg 2.2
  + Make $gnupg->call('foo') update the internal GnuPG version number
  + Localize tainted PATH env to make exec happy
- remove t/get_public_keys.t as it tries to fetch keys from the
  internet, which is not possible in restricted build environments
- use new upstream source url
* Thu Aug  6 2020 Tina Müller <tina.mueller@suse.com>
- Remove patches gpg2.2.6_7c85ac40660861e7507c43d043323c3f1b83921b.patch,
  gpg2.2.8_b356e7fda15e39e037da1888a24000a96fc85c90.patch (not needed anymore)
* Thu Aug  6 2020 Tina Müller <tina.mueller@suse.com>
- Remove 1.patch (not needed anymore)
* Sat May 16 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.00
  see /usr/share/doc/packages/perl-GnuPG-Interface/Changes
  1.0 - 2020-05-13
  - Limit support to GnuPG 2.2+ and 1.4
  - Additional information from keys when using GnuPG 2.2 or higher
  - Add support for use of agent/pinentry
  - Updated options to add ignore_mdc_error and logging
  - Improvements to tests
  - Update pubkey_data documentation
  - Special thanks to dkg on Github for a large PR with updates for GnuPG 2
  - Thanks also to ntyni on Github for a pointer to test updates also dealing
    with version changes
* Thu Mar 14 2019 Lars Vogdt <lars@linux-schulserver.de>
- disable the tests for old SUSE distributions: they are using a
  too old gpg version
* Tue Feb  5 2019 Stephan Kulow <coolo@suse.com>
- Align cpanspec.yml
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix build
  Add 1.patch to fix newer GnuPG versions
  and gpg2.2.6_7c85ac40660861e7507c43d043323c3f1b83921b.patch and
  gpg2.2.8_b356e7fda15e39e037da1888a24000a96fc85c90.patch for further
  changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.52
  see /usr/share/doc/packages/perl-GnuPG-Interface/Changes
  0.52 - 2016-02-16
  - Skip "grp" records, generated by GPG 2.1; this suppresses "unknown
    record type" warnings
  - Add explicit Fatal dependency; though nominally part of code perl,
    RedHat's perl does not ship with it
  - Ensure that the trustdb is created before attempting to encrypt; gpg2
    requires that it exist, even for commands with --trust-model=always.
    See https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=751266
* Mon Dec 29 2014 lars@linux-schulserver.de
- updated to 0.51:
  + Update README file
  + Work around gpg2 bug by omitting --homedir during symmetric
    encryption
- change permission of test homedir to avoid warnings during tests
* Mon Sep 15 2014 coolo@suse.com
- updated to 0.50
  0.50 - 2014-03-14
  - Version 0.49 implicitly required Moose; switch to a technique that
    does not
  - Modernize CHANGES
  0.49 - 2014-03-13
  - Restore context-sensitive (array/arrayref) behavior of multiple array
    methods from 0.46.
  - Fix MANIFEST/.gitignore inconsistency
  0.48 - 2014-03-10
  - Switch from --always-trust to --trust-model=always
  0.47 - 2014-03-10
  - No changes from 0.47_02
  0.47_02 - 2014-02-14
  - Remove a stray 'use Data::Dumper::Concise' added in 0.47_01
  0.47_01 - 2014-01-27
  - Switch from Any::Moose to Moo
  - Accept "gpg (GnuPG/MacGPG2)" as a valid gpg version
  - Typo fixes in documentation
* Wed Sep 25 2013 coolo@suse.com
- rerun make test twice - the trustdb needs to be created for
  the test to succeed (broken test)
  reported as https://rt.cpan.org/Public/Bug/Display.html?id=88963
* Thu Jun 20 2013 coolo@suse.com
- updated to 0.46
    Add a ->search_keys method
    Add a ->version method
    Remove dead code for finding gnupg2 binary
    Include trailing columns when parsing --fixed-list-mode output
* Sat Oct 15 2011 coolo@suse.com
- updated to 0.44
    Bump Math::BigInt dependency to get the new 'try GMP' syntax.
* Thu Mar 31 2011 coolo@novell.com
- update to 0.43:
    Additional cleanups from dkg
    GnuPG::Revoker: improve docs, compare() should fail if the signature counts differ - dkg
    Handle revoker packets (rvk) - dkg
    Move compare() into GnuPG::Signature, got rid of t/GnuPG/ComparableSignature.pm - dkg
    Move signature comparison into ComparableKey.pm instead of ComparableSubKey.pm - dkg
    Move fingerprint comparison directly into GnuPG::Fingerprint - dkg
    Change around some variable names for consistency's sake:
    $current_key becomes $current_primary_key
    $current_fingerprinted_key becomes $current_key  -dkg
    Fixed synopsis example in GnuPG::Signature pod - dkg
    Allow for primary key to have per-key (useful for signatures of class 0x1f, see http://tools.ietf.org/html/rfc4880#section-5.2.1) - dkg
    Add revocations to keys and user ids and user attributes - dkg
    Add signature class and exportability to GnuPG::Signature - dkg
    Introduced GnuPG::UserAttribute to handle uat packets - dkg
    Actually check validity of signatures and report them - dkg
    Support more than 1 signature over each subkey - dkg
    Do not bother shipping test/random_seed - dkg
    Fix copy method of GnuPG::Options.
    The result of not checking for definedness here is to never copy the
    meta_immutable value successfully (as that is true by default).  This led
    to a FTBFS (failure to build from source) when running non-interactively.
    See also:  http://bugs.debian.org/549743  - Tim Retout
    Expose signature expiration times - dkg
    Take advantage of --fixed-list-mode and report timestamps at 1Hz precision instead of daily precision - dkg
    Always use --fixed-list-mode for consistency and better granularity of data - dkg
    Unescape strings to handle User IDs with colons in them - dkg
    Add usage_flags to keys - dkg
    Several doc patches from Daniel Kahn Gillmor
    Fix for documented typos reported by SYSMON Fixes rt.cpan.org#50377 - jesse
    Fix POD errors - alexmv
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Jul 16 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 0.42
